@@ -1,11 +1,14 @@
 
 from django import forms
 from django.utils.translation import ugettext_lazy as _
+from django.template.loader import render_to_string
 
 from categories.models import Category
 from cap.fields import DatePickerField
 from basement.utils import get_date_from_request
 
+from apps.products.models import Product
+
 
 class SearchProductForm(forms.Form):
 
@@ -65,8 +68,6 @@ class ReportForm(forms.Form):
             }
         )
 
-        self.is_valid()
-
 
 class InvoiceTypeSelectForm(forms.Form):
 
@@ -75,3 +76,33 @@ class InvoiceTypeSelectForm(forms.Form):
         super().__init__(*args, **kwargs)
 
         self.fields['type'] = forms.ChoiceField(choices=types)
+
+
+class ProductSelectForm(forms.Form):
+    product = forms.ModelChoiceField(queryset=Product.objects.all())
+
+
+class SetDiscountForm(forms.Form):
+    value = forms.IntegerField()
+
+
+class SetQtyForm(forms.Form):
+    value = forms.IntegerField()
+
+
+class SetPriceForm(forms.Form):
+    value = forms.FloatField()
+
+
+class AddProductForm(forms.ModelForm):
+
+    stock = forms.IntegerField(label=_('Stock'), min_value=1)
+
+    class Meta:
+        model = Product
+        fields = [
+            'category',
+            'name',
+            'stock',
+            'price_retail'
+        ]
