@@ -4,7 +4,7 @@ SelectServiceItemList = function (params) {
     var $container = params.$container;
 
     function handleListItemDoubleClick() {
-        $(window).trigger('service-selected', [$(this).data('item-id')]);
+        $(window).trigger('service_item-selected', [$(this).data('item-id')]);
     }
 
     $container.on('dblclick', '[data-role=list-item]', handleListItemDoubleClick);
